Shiny: C++ Profiler: C:/Documents and Settings/aiab1355/Desktop/shiny/include/ShinyDoc.h File Reference

- Main Page
- Files

# C:/Documents and Settings/aiab1355/Desktop/shiny/include/ShinyDoc.h File Reference

Go to the source code of this file.

## Defines
#define | PROFILE_FUNC()
| Profile the caller function.
#define | PROFILE_CODE(code)
| Profile and execute the specified code.
#define | PROFILE_BLOCK(name)
| Profile the caller block.
#define | PROFILE_BEGIN()
| Profile until PROFILE_END.
#define | PROFILE_()
| short

## Define Documentation

#define PROFILE_ | ( |  | ) |

short

{Specialisation offered by the function A}

Note:
  Must only be called at most once per function

Parameters:

  | {details | of 1st parameters used}
  | {details | of 2nd parameters used}
  | {etc...} |

Returns:
  {details of any return values}

    {working example}
    \b Output:
    {output from working example}

See also:
  PROFILE_CODE PROFILE_BLOCK PROFILE_BEGIN PROFILE_UPDATE_ALL PROFILE_OUTPUT_ALL

#define PROFILE_BEGIN | ( |  | ) |

Profile until PROFILE_END.

This will create and begin a profile with the specified name until PROFILE_END is called. Call PROFILE_END to end profile.

Note:
  When the profile is finished program must call PROFILE_END.

Parameters:

  | Name | of profile to be created. Name is an identifier (not a string) and uses C++ naming rules

    {working example}
    \b Output:
    {output from working example}

See also:
  PROFILE_FUNC PROFILE_CODE PROFILE_BLOCK PROFILE_UPDATE_ALL PROFILE_OUTPUT_ALL

#define PROFILE_BLOCK | ( | name |  | ) |

Profile the caller block.

This will create and begin a profile with the specified name until end of block. Call this in the beginning of your code block (function, for-loop, if-statment, etc).

Note:
  Must only be called at most once per code block

Parameters:

  | Name | of profile to be created. Name is an identifier (not a string) and uses C++ naming rules

    {working example}
    \b Output:
    {output from working example}

See also:
  PROFILE_FUNC PROFILE_CODE PROFILE_BEGIN PROFILE_UPDATE_ALL PROFILE_OUTPUT_ALL

#define PROFILE_CODE | ( | code |  | ) |

Profile and execute the specified code.

This will create and begin a profile, execute code, and end profile. PROFILE_CODE is typically used when you want to profile a function call without touching the function source code or profiling every call.

Note:
  Any return value from the executed code will be lost

Parameters:

  | Code | to be executed and profiled

    {working example}
    \b Output:
    {output from working example}

See also:
  PROFILE_FUNC PROFILE_BLOCK PROFILE_BEGIN PROFILE_UPDATE_ALL PROFILE_OUTPUT_ALL

#define PROFILE_FUNC | ( |  | ) |

Profile the caller function.

This will create and begin a profile with the caller function name until end of block. Call this in the beginning of your function.

Note:
  Must only be called at most once per function

    {working example}
    \b Output:
    {output from working example}

See also:
  PROFILE_CODE PROFILE_BLOCK PROFILE_BEGIN PROFILE_UPDATE_ALL PROFILE_OUTPUT_ALL

Copyright © 2007-2008 by Aidin Abedi